@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2023 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2024 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -197,6 +197,7 @@ private slots:
     void onPermissionDenied();
     void onOpeningUneditable();
     void onOpeningNonexistent();
+    void columnWarning();
     void autoSave();
     void pauseAutoSaving (bool pause);
     void enforceLang (QAction *action);
@@ -273,7 +274,6 @@ private:
     QActionGroup *aGroup_;
     QString lastFile_; // The last opened or saved file (for file dialogs).
     QHash<QString, QVariant> lastWinFilesCur_; // The last window files and their cusrors (if restored).
-    QString txtReplace_; // The replacing text.
     int rightClicked_; // The index/row of the right-clicked tab/item.
     int loadingProcesses_; // The number of loading processes (used to prevent early closing).
     QMetaObject::Connection lambdaConnection_; // Captures a lambda connection to disconnect it later.
