@@ -517,7 +517,11 @@ void Highlighter::highlightJsonBlock (const QString &text)
     if (mainFormatting)
     {
         data->setHighlighted();
+#if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
+        for (const HighlightingRule &rule : std::as_const (highlightingRules))
+#else
         for (const HighlightingRule &rule : qAsConst (highlightingRules))
+#endif
         {
             if (rule.format == whiteSpaceFormat)
             {
